#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-flit-core%{psuffix}
Version:        3.6.0
Release:        bp154.1.56
Summary:        Distribution-building parts of Flit
License:        BSD-3-Clause
URL:            https://github.com/pypa/flit
Source0:        https://files.pythonhosted.org/packages/source/f/flit-core/flit_core-%{version}.tar.gz
Source1:        https://github.com/pypa/flit/raw/%{version}/flit_core/build_dists.py
BuildRequires:  %{python_module base >= 3.6}
%if %{with test}
BuildRequires:  %{python_module flit-core = %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testpath}
%endif
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-tomli
BuildArch:      noarch
%python_subpackages

%description
Flit is a simple way to put Python packages and modules on PyPI.

%prep
%setup -q -n flit_core-%{version}
cp %{SOURCE1} .

%build
# https://flit.readthedocs.io/en/latest/bootstrap.html
python3 build_dists.py

%if !%{with test}
%install
%{python_expand # do manually what pip would do
mkdir -p %{buildroot}%{$python_sitelib}
unzip dist/flit_core-%{version}-py3-none-any.whl -d %{buildroot}%{$python_sitelib}
rm -r  %{buildroot}%{$python_sitelib}/flit_core/tests
}
%{python_expand # debundle after the bootstrap. See vendor/README
sed -i 's/from .vendor import tomli/import tomli/'  %{buildroot}%{$python_sitelib}/flit_core/config.py
rm -r %{buildroot}%{$python_sitelib}/flit_core/vendor
}
%{?python_compileall}
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# make sure we do not test the sources but the debundled package
rm flit_core/*.py pyproject.toml
%pytest -rfEs
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/flit_core
%{python_sitelib}/flit_core-%{version}*-info
%endif

%changelog
* Sun Jan  9 2022 Ben Greiner <code@bnavigator.de>
- Back to bootstrap without pip
* Sun Jan  9 2022 Ben Greiner <code@bnavigator.de>
- Update to version 3.6
  * flit_core now bundles the tomli TOML parser library (version
    1.2.3) to avoid a circular dependency between flit_core and
    tomli (:ghpull:`492`). This means flit_core now has no
    dependencies except Python itself, both at build time and at
    runtime, simplifying :doc:`bootstrapping <bootstrap>`.
- The above is not fully applicale to openSUSE, we debundle.
- Release notes for Version 3.5.1
  * Fix development installs with flit install --symlink and
  - -pth-file, which were broken in 3.5.0, especially for packages
    using a src folder (:ghpull:`472`).
- Release notes for Version 3.5
  * You can now use Flit to distribute a module or package inside a
    namespace package (as defined by PEP 420). To do this, specify
    the import name of the concrete, inner module you are packaging
  - e.g. name = "sphinxcontrib.foo" - either in the [project]
    table, or under [tool.flit.module] if you want to use a
    different name on PyPI (:ghpull:`468`).
  * Flit no longer generates a setup.py file in sdists (.tar.gz
    packages) by default (:ghpull:`462`). Modern packaging tools
    don't need this. You can use the --setup-py flag to keep adding
    it for now, but this will probably be removed at some point in
    the future.
  * Fixed how flit init handles authors' names with non-ASCII
    characters (:ghpull:`460`).
  * When flit init generates a LICENSE file, the new pyproject.toml
    now references it (:ghpull:`467`).
- Do not package tests
- Make it work with old python-rpm-macros
* Fri Oct 15 2021 Ben Greiner <code@bnavigator.de>
- Break build cycle by using upstream recommended bootstrap method
  https://flit.readthedocs.io/en/latest/bootstrap.html
* Fri Oct 15 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 3.4
  * Python 3.6 or above is now required, both for flit and
    flit_core.
  * Add a --setup-py option to flit build and flit publish,
    and a warning when neither this nor --no-setup-py are
    specified (PR #431). A future version will stop
    generating setup.py files in sdists by default.
  * Add support for standardised editable installs - pip
    install -e - according to PEP 660 (PR #400).
  * Add a --pypirc option for flit publish to specify an
    alternative path to a .pypirc config file describing
    package indexes (PR #434).
  * Fix installing dependencies specified in a [project]
    table (PR #433)
  * Fix building wheels when SOURCE_DATE_EPOCH (see
    Reproducible builds) is set to a date before 1980 (PR
    [#448]).
  * Switch to using the tomli TOML parser, in common with
    other packaging projects (PR #438). This supports TOML
    version 1.0.
  * Add a document on Bootstrapping (PR #441).
- Release Version 3.3
  * PKG-INFO files in sdists are now generated the same way
    as METADATA in wheels, fixing some issues with sdists
    (PR #410).
  * flit publish now sends SHA-256 hashes, fixing uploads
    to GitLab package repositories (PR #416).
  * The [project] metadata table from PEP 621 is now fully
    supported and documented. Projects using this can now
    specify requires = ["flit_core >=3.2,<4"] in the
    [build-system] table.
- Multibuild: break another depcycle with
  pytest/importlib-metadata/tomli
* Wed Apr 14 2021 Matthias Bach <marix@marix.org>
- Update to version 3.2
  * Experimental support for specifying metadata in a [project] in
    pyproject.toml table as specified by PEP-621.
  * Fix writing METADATA file with multi-line information in
    certain fields such as Author.
  * Fix building wheel when a directory such as LICENSES appears
    in the project root directory.
  * Switch from the deprecated pytoml package to toml.
* Mon Oct 26 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 3.0
  * flit_core once again requires Python 3 (>=3.4). Packages that
    support Python 2 can still be built by flit_core 2.x, but can't
    rely on new features (:ghpull:`342`).
- Kill dephell dependency
* Mon Mar 23 2020 Matej Cepl <mcepl@suse.com>
- Add macro %%dephell_genspec to generate setup.py
* Sun Mar 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix generating with new dephell
* Wed Dec 18 2019 John Vandenberg <jayvdb@gmail.com>
- Remove dephell build workaround
* Mon Dec 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.1.0
